/* 
 *   FILE: iswitchwin-application.h --
 * AUTHOR: Martin Man <mman@martinman.net>
 *   DATE: 28 December 2005
 *
 * Copyright (c) 2005 Martin Man.
 *
 * This application is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this application; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __ISWITCHWIN_APPLICATION_H__
#define __ISWITCHWIN_APPLICATION_H__

#include <dbus/dbus-glib-bindings.h>
#include <glade/glade.h>
#include <gtk/gtk.h>

G_BEGIN_DECLS

#define ISWITCHWIN_TYPE_APPLICATION \
    (iswitchwin_application_get_type())

#define ISWITCHWIN_APPLICATION(object) \
    (G_TYPE_CHECK_INSTANCE_CAST((object), \
                                ISWITCHWIN_TYPE_APPLICATION, \
                                ISwitchWinApplication))

#define ISWITCHWIN_APPLICATION_CLASS(klass) \
    (G_TYPE_CHACK_CLASS_CAST((klass), \
                             ISWITCHWIN_TYPE_APPLICATION, \
                             ISwitchWinApplicationClass))

#define ISWITCHWIN_IS_APPLICATION(object) \
    (G_TYPE_CHECK_INSTANCE_TYPE((object), \
                                ISWITCHWIN_TYPE_APPLICATION))

#define ISWITCHWIN_IS_APPLICATION_CLASS(klass) \
    (G_TYPE_CHECK_CLASS_TYPE((klass), \
                             ISWITCHWIN_TYPE_APPLICATION))

#define ISWITCHWIN_APPLICATION_GET_CLASS(object) \
    (G_TYPE_INSTANCE_GET_CLASS((object), \
                               ISWITCHWIN_TYPE_APPLICATION, \
                               ISwitchWinApplicationClass))

typedef struct _ISwitchWinApplication ISwitchWinApplication;
typedef struct _ISwitchWinApplicationClass ISwitchWinApplicationClass;

struct _ISwitchWinApplication
{
  GObject parent_instance;

  /** Glade UI */
  GladeXML * xml;
  /** Top Level Window */
  GtkWidget * toplevel;
  /** Typeahead Entry */
  GtkWidget * filter;
  /** Tree View */
  GtkWidget * treeview;
  /** Tree Model (Windows we can switch to) */
  GtkListStore * model;
  /** List of all WnckWindows we can switch to */
  GList * all_windows;
  /** List of WnckWindows matching typeahead string */
  GList * switchable_windows;
  /** Number of entries in a list */
  int n_entries;

  /** Message bus */
  DBusGConnection * connection;
};

struct _ISwitchWinApplicationClass
{
  GObjectClass parent_class;
};

GType
iswitchwin_application_get_type( void );

ISwitchWinApplication *
iswitchwin_application_new();

gboolean
iswitchwin_application_build_ui(
        ISwitchWinApplication * application,
        GladeXML * xml );

gboolean
iswitchwin_application_register_service(
        ISwitchWinApplication * application );

void
iswitchwin_application_shutdown(
       ISwitchWinApplication * application );

void
iswitchwin_application_open_window(
        ISwitchWinApplication * application,
        guint32 timestamp );

void
iswitchwin_application_open_remote_window(
        ISwitchWinApplication * application );

void
iswitchwin_application_query_window_list(
        ISwitchWinApplication * application );

void
iswitchwin_application_repaint_window_list(
        ISwitchWinApplication * application );

void
iswitchwin_application_activate_selected_window(
        ISwitchWinApplication * application );

enum {
    COLUMN_ICON,
    COLUMN_NAME,
    COLUMN_WORKSPACE,
    COLUMN_WNCK_WINDOW,
    N_COLUMNS
};

G_END_DECLS

#endif /* __ISWITCHWIN_APPLICATION_H__ */

/* vim: set et ts=4 sw=4 tw=76:
 */
