/* 
 *   FILE: main.c --
 * AUTHOR: Martin Man <mman@martinman.net>
 *   DATE: 28 December 2005
 *
 * Copyright (c) 2005 Martin Man.
 *
 * This application is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this application; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/* yes we really know wnck API is unstable */
#define WNCK_I_KNOW_THIS_IS_UNSTABLE 1

#include <stdio.h>
#include <stdlib.h>

#include <gtk/gtk.h>
#include <glade/glade.h>

#include <libintl.h>
#include <locale.h>
#define _(text) gettext(text)

#include "src/iswitchwin-application.h"

#define UIFILE "iswitchwinui.glade"

int main( int argc, char * argv [] )
{
    gchar * uifile = NULL;
    GladeXML * uixml = NULL;
    ISwitchWinApplication * app = NULL;

    /* support i18n */
#ifdef ENABLE_NLS
    setlocale( LC_ALL, "" );
    bindtextdomain( GETTEXT_PACKAGE, LOCALE_DIR );
    bind_textdomain_codeset( GETTEXT_PACKAGE, "UTF-8" );
    textdomain( GETTEXT_PACKAGE );
#endif

    /* initialize gtk library */
    gtk_init( &argc, &argv );

    /* create application object, for now without UI */
    app = iswitchwin_application_new( uixml );

    /* register us at the message bus, if already registered, bring up the
     * already running application window */
    if( ! iswitchwin_application_register_service( app ) ) {
        iswitchwin_application_open_remote_window( app );
        return 0;
    }

    /* we should be registered as a service, continue with UI setup */

    /* try to find our glade file */
    uifile = g_build_filename( UIFILE, NULL );
    if( ! g_file_test( uifile, G_FILE_TEST_EXISTS ) ) {
        uifile = g_build_filename( "src", UIFILE, NULL );
        if( ! g_file_test( uifile, G_FILE_TEST_EXISTS ) ) {
            uifile = g_build_filename( GLADEDATADIR, UIFILE, NULL );
            if( ! g_file_test( uifile, G_FILE_TEST_EXISTS ) ) {
                fprintf( stderr, "ERROR: unable to find %s\n", uifile );
                exit( 0 );
            }
        }
    }

    /* try to load our ui from glade file */
    uixml = glade_xml_new( uifile, NULL, NULL );

    /* build UI and bring up window */
    iswitchwin_application_build_ui( app, uixml );
    iswitchwin_application_open_window( app, 0 );

    /* enter main event loop */
    gtk_main();

    return 0;
}

/* vim: set et ts=4 sw=4 tw=76:
 */
